@@ -10,15 +10,9 @@ pub trait Codec: Sync + Send + Clone + Default {
     fn decode<T: DeserializeOwned>(&self, arg: &[u8]) -> Result<T, Error>;
 }
 
-#[derive(Debug, Clone, Copy)]
+#[derive(Debug, Clone, Copy, Default)]
 pub struct JsonCodec {}
 
-impl Default for JsonCodec {
-    fn default() -> Self {
-        JsonCodec {}
-    }
-}
-
 impl Codec for JsonCodec {
     fn encode<T: Serialize>(&self, arg: T) -> Result<Vec<u8>, Error> {
         match serde_json::to_vec(&arg) {
@@ -39,15 +33,9 @@ impl Codec for JsonCodec {
     }
 }
 
-#[derive(Debug, Clone, Copy)]
+#[derive(Debug, Clone, Copy, Default)]
 pub struct BinCodec {}
 
-impl Default for BinCodec {
-    fn default() -> Self {
-        BinCodec {}
-    }
-}
-
 impl Codec for BinCodec {
     fn encode<T: Serialize>(&self, arg: T) -> Result<Vec<u8>, Error> {
         match bincode::serialize(&arg) {
